@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 S[&]T, The Netherlands.
+ * Copyright (C) 2015-2021 S[&]T, The Netherlands.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -480,11 +480,11 @@ static int init_product_definition(harp_ingestion_module *module, int version)
                                                                      NULL, read_data_source);
     harp_variable_definition_add_mapping(variable_definition, NULL, NULL, "/@DATA.SOURCE", NULL);
 
-    /* site_name */
+    /* location_name */
     description = "name of the site at which the sensor is located";
-    variable_definition = harp_ingestion_register_variable_full_read(product_definition, "site_name", harp_type_string,
-                                                                     0, NULL, NULL, description, NULL, NULL,
-                                                                     read_data_location);
+    variable_definition = harp_ingestion_register_variable_full_read(product_definition, "location_name",
+                                                                     harp_type_string, 0, NULL, NULL, description, NULL,
+                                                                     NULL, read_data_location);
     harp_variable_definition_add_mapping(variable_definition, NULL, NULL, "/@DATA.LOCATION", NULL);
 
     /* datetime */
