@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 S[&]T, The Netherlands.
+ * Copyright (C) 2015-2021 S[&]T, The Netherlands.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -63,6 +63,7 @@ typedef enum harp_operation_type_enum
     operation_membership_filter,
     operation_point_distance_filter,
     operation_point_in_area_filter,
+    operation_rebin,
     operation_regrid,
     operation_regrid_collocated_dataset,
     operation_regrid_collocated_product,
@@ -135,6 +136,7 @@ typedef enum harp_membership_operator_type_enum
  *   |-  harp_operation_exclude_variable
  *   |-  harp_operation_flatten
  *   |-  harp_operation_keep_variable
+ *   |-  harp_operation_rebin
  *   |-  harp_operation_regrid
  *   |-  harp_operation_regrid_collocated_dataset
  *   |-  harp_operation_regrid_collocated_product
@@ -155,39 +157,39 @@ typedef struct harp_operation_struct
 typedef struct harp_operation_numeric_value_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_numeric_value_filter_struct *, harp_data_type, void *);
+    int (*eval)(struct harp_operation_numeric_value_filter_struct *, harp_data_type, void *);
 } harp_operation_numeric_value_filter;
 
 typedef struct harp_operation_string_value_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_string_value_filter_struct *, int num_enum_values, char **enum_name,
-                 harp_data_type, void *);
+    int (*eval)(struct harp_operation_string_value_filter_struct *, int num_enum_values, char **enum_name,
+                harp_data_type, void *);
 } harp_operation_string_value_filter;
 
 typedef struct harp_operation_index_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_index_filter_struct *, int32_t);
+    int (*eval)(struct harp_operation_index_filter_struct *, int32_t);
     harp_dimension_type dimension_type;
 } harp_operation_index_filter;
 
 typedef struct harp_operation_point_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_point_filter_struct *, harp_spherical_point *);
+    int (*eval)(struct harp_operation_point_filter_struct *, harp_spherical_point *);
 } harp_operation_point_filter;
 
 typedef struct harp_operation_polygon_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_polygon_filter_struct *, harp_spherical_polygon *);
+    int (*eval)(struct harp_operation_polygon_filter_struct *, harp_spherical_polygon *);
 } harp_operation_polygon_filter;
 
 typedef struct harp_operation_area_covers_area_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_area_covers_area_filter_struct *, harp_spherical_polygon *);
+    int (*eval)(struct harp_operation_area_covers_area_filter_struct *, harp_spherical_polygon *);
     /* parameters */
     char *filename;     /* can be NULL */
     /* extra */
@@ -197,7 +199,7 @@ typedef struct harp_operation_area_covers_area_filter_struct
 typedef struct harp_operation_area_covers_point_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_area_covers_point_filter_struct *, harp_spherical_polygon *);
+    int (*eval)(struct harp_operation_area_covers_point_filter_struct *, harp_spherical_polygon *);
     /* parameters */
     harp_spherical_point point;
 } harp_operation_area_covers_point_filter;
@@ -205,7 +207,7 @@ typedef struct harp_operation_area_covers_point_filter_struct
 typedef struct harp_operation_area_inside_area_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_area_inside_area_filter_struct *, harp_spherical_polygon *);
+    int (*eval)(struct harp_operation_area_inside_area_filter_struct *, harp_spherical_polygon *);
     /* parameters */
     char *filename;     /* can be NULL */
     /* extra */
@@ -215,7 +217,7 @@ typedef struct harp_operation_area_inside_area_filter_struct
 typedef struct harp_operation_area_intersects_area_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_area_intersects_area_filter_struct *, harp_spherical_polygon *);
+    int (*eval)(struct harp_operation_area_intersects_area_filter_struct *, harp_spherical_polygon *);
     /* parameters */
     char *filename;     /* can be NULL */
     int has_fraction;
@@ -253,7 +255,7 @@ typedef struct harp_operation_bin_with_variables_struct
 typedef struct harp_operation_bit_mask_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_bit_mask_filter_struct *, harp_data_type, void *);
+    int (*eval)(struct harp_operation_bit_mask_filter_struct *, harp_data_type, void *);
     /* parameters */
     char *variable_name;
     harp_bit_mask_operator_type operator_type;
@@ -273,7 +275,7 @@ typedef struct harp_operation_clamp_struct
 typedef struct harp_operation_collocation_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_collocation_filter_struct *, harp_data_type, void *);
+    int (*eval)(struct harp_operation_collocation_filter_struct *, harp_data_type, void *);
     /* parameters */
     char *filename;
     harp_collocation_filter_type filter_type;
@@ -289,7 +291,7 @@ typedef struct harp_operation_collocation_filter_struct
 typedef struct harp_operation_comparison_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_comparison_filter_struct *, harp_data_type, void *);
+    int (*eval)(struct harp_operation_comparison_filter_struct *, harp_data_type, void *);
     /* parameters */
     char *variable_name;
     harp_comparison_operator_type operator_type;
@@ -358,7 +360,7 @@ typedef struct harp_operation_flatten_struct
 typedef struct harp_operation_index_comparison_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_index_comparison_filter_struct *, int32_t);
+    int (*eval)(struct harp_operation_index_comparison_filter_struct *, int32_t);
     harp_dimension_type dimension_type;
     /* parameters */
     harp_comparison_operator_type operator_type;
@@ -368,7 +370,7 @@ typedef struct harp_operation_index_comparison_filter_struct
 typedef struct harp_operation_index_membership_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_index_membership_filter_struct *, int32_t);
+    int (*eval)(struct harp_operation_index_membership_filter_struct *, int32_t);
     harp_dimension_type dimension_type;
     /* parameters */
     harp_membership_operator_type operator_type;
@@ -387,7 +389,7 @@ typedef struct harp_operation_keep_variable_struct
 typedef struct harp_operation_longitude_range_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_longitude_range_filter_struct *, harp_data_type, void *);
+    int (*eval)(struct harp_operation_longitude_range_filter_struct *, harp_data_type, void *);
     /* parameters */
     double min;
     double max;
@@ -398,7 +400,7 @@ typedef struct harp_operation_longitude_range_filter_struct
 typedef struct harp_operation_membership_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_membership_filter_struct *, harp_data_type, void *);
+    int (*eval)(struct harp_operation_membership_filter_struct *, harp_data_type, void *);
     /* parameters */
     char *variable_name;
     harp_membership_operator_type operator_type;
@@ -412,7 +414,7 @@ typedef struct harp_operation_membership_filter_struct
 typedef struct harp_operation_point_distance_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_point_distance_filter_struct *, harp_spherical_point *);
+    int (*eval)(struct harp_operation_point_distance_filter_struct *, harp_spherical_point *);
     /* parameters */
     harp_spherical_point point;
     double distance;
@@ -421,13 +423,20 @@ typedef struct harp_operation_point_distance_filter_struct
 typedef struct harp_operation_point_in_area_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_point_in_area_filter_struct *, harp_spherical_point *);
+    int (*eval)(struct harp_operation_point_in_area_filter_struct *, harp_spherical_point *);
     /* parameters */
     char *filename;     /* can be NULL */
     /* extra */
     harp_area_mask *area_mask;
 } harp_operation_point_in_area_filter;
 
+typedef struct harp_operation_rebin_struct
+{
+    harp_operation_type type;
+    /* parameters */
+    harp_variable *axis_bounds_variable;
+} harp_operation_rebin;
+
 typedef struct harp_operation_regrid_struct
 {
     harp_operation_type type;
@@ -520,8 +529,8 @@ typedef struct harp_operation_squash_struct
 typedef struct harp_operation_string_comparison_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_string_comparison_filter_struct *, int num_enum_values, char **enum_name,
-                 harp_data_type, void *);
+    int (*eval)(struct harp_operation_string_comparison_filter_struct *, int num_enum_values, char **enum_name,
+                harp_data_type, void *);
     /* parameters */
     char *variable_name;
     harp_comparison_operator_type operator_type;
@@ -531,8 +540,8 @@ typedef struct harp_operation_string_comparison_filter_struct
 typedef struct harp_operation_string_membership_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_string_membership_filter_struct *, int num_enum_values, char **enum_name,
-                 harp_data_type, void *);
+    int (*eval)(struct harp_operation_string_membership_filter_struct *, int num_enum_values, char **enum_name,
+                harp_data_type, void *);
     /* parameters */
     char *variable_name;
     harp_membership_operator_type operator_type;
@@ -543,7 +552,7 @@ typedef struct harp_operation_string_membership_filter_struct
 typedef struct harp_operation_valid_range_filter_struct
 {
     harp_operation_type type;
-    int (*eval) (struct harp_operation_valid_range_filter_struct *, harp_data_type, void *);
+    int (*eval)(struct harp_operation_valid_range_filter_struct *, harp_data_type, void *);
     /* parameters */
     char *variable_name;
     /* extra */
@@ -636,6 +645,9 @@ int harp_operation_point_distance_filter_new(double latitude, const char *latitu
 int harp_operation_point_in_area_filter_new(const char *filename, int num_latitudes, double *latitude,
                                             const char *latitude_unit, int num_longitudes, double *longitude,
                                             const char *longitude_unit, harp_operation **operation);
+int harp_operation_rebin_new(harp_dimension_type dimension_type, const char *axis_bounds_variable_name,
+                             const char *axis_unit, long num_bounds_values, double *bounds_values,
+                             harp_operation **new_operation);
 int harp_operation_regrid_new(harp_dimension_type dimension_type, const char *axis_variable_name, const char *axis_unit,
                               long num_values, double *values, long num_bounds_values, double *bounds_values,
                               harp_operation **new_operation);
