@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 S[&]T, The Netherlands.
+ * Copyright (C) 2015-2021 S[&]T, The Netherlands.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -963,8 +963,12 @@ static int add_missing_count_and_weight_variables(harp_product *product, harp_pr
                         }
                         for (j = 1; j < variable->num_dimensions; j++)
                         {
-                            if (harp_variable_add_dimension(new_variable, j, variable->dimension_type[j],
-                                                            variable->dimension[j]) != 0)
+                            long dim_length;
+
+                            dim_length = variable->dimension_type[j] < 0 ? variable->dimension[j] :
+                                product->dimension[variable->dimension_type[j]];
+                            if (harp_variable_add_dimension(new_variable, j, variable->dimension_type[j], dim_length) !=
+                                0)
                             {
                                 harp_variable_delete(new_variable);
                                 return -1;
@@ -1034,8 +1038,12 @@ static int add_missing_count_and_weight_variables(harp_product *product, harp_pr
                         }
                         for (j = weight_variable->num_dimensions; j < variable->num_dimensions; j++)
                         {
-                            if (harp_variable_add_dimension(new_variable, j, variable->dimension_type[j],
-                                                            variable->dimension[j]) != 0)
+                            long dim_length;
+
+                            dim_length = variable->dimension_type[j] < 0 ? variable->dimension[j] :
+                                product->dimension[variable->dimension_type[j]];
+                            if (harp_variable_add_dimension(new_variable, j, variable->dimension_type[j], dim_length) !=
+                                0)
                             {
                                 harp_variable_delete(new_variable);
                                 return -1;
@@ -1822,7 +1830,7 @@ LIBHARP_API int harp_product_verify(const harp_product *product)
  * \param print Print function to use
  */
 LIBHARP_API void harp_product_print(const harp_product *product, int show_attributes, int show_data,
-                                    int (*print) (const char *, ...))
+                                    int (*print)(const char *, ...))
 {
     int i;
 
