@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 S[&]T, The Netherlands.
+ * Copyright (C) 2015-2021 S[&]T, The Netherlands.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -67,6 +67,7 @@ static long get_unpadded_length(double *vector, long vector_length)
 
 static resample_type get_resample_type(harp_variable *variable, harp_dimension_type dimension_type)
 {
+    long variable_name_length = (long)strlen(variable->name);
     int num_matching_dims;
     int i;
 
@@ -74,16 +75,12 @@ static resample_type get_resample_type(harp_variable *variable, harp_dimension_t
     {
         /* also remove these variables if they are provided as scalars (without time dimension) */
 
-        /* we can't interpolate these datetime boundary edge values */
-        if (strcmp(variable->name, "datetime_start") == 0 || strcmp(variable->name, "datetime_stop") == 0)
+        /* we can't interpolate these datetime boundary edge/length values (same issue as _bounds variables) */
+        if (strcmp(variable->name, "datetime_start") == 0 || strcmp(variable->name, "datetime_stop") == 0 ||
+            strcmp(variable->name, "datetime_length") == 0)
         {
             return resample_remove;
         }
-        /* datetime_length requires interval interpolation which is currently not supported for the time dimension */
-        if (strcmp(variable->name, "datetime_length") == 0)
-        {
-            return resample_interval;
-        }
     }
 
     /* ensure that there is only 1 dimension of the given type */
@@ -116,8 +113,7 @@ static resample_type get_resample_type(harp_variable *variable, harp_dimension_t
 
     if (num_matching_dims != 1)
     {
-        /* remove all variables with more than one matching dimension */
-        /* TODO: how to resample 2D AVKs */
+        /* remove all variables with more than one matching dimension (including 2D AVKs) */
         return resample_remove;
     }
 
@@ -135,15 +131,17 @@ static resample_type get_resample_type(harp_variable *variable, harp_dimension_t
 
     if (dimension_type == harp_dimension_vertical)
     {
-        /* use interval interpolation for vertical regridding of 1D column AVKs */
-        if (strstr(variable->name, "_avk") != NULL)
-        {
-            return resample_interval;
-        }
         /* use interval interpolation for vertical regridding of partial column profiles */
         if (strstr(variable->name, "_column_") != NULL)
         {
-            return resample_interval;
+            /* only when this is a density quantity, the column avk, or the dfs */
+            if (strcmp(&variable->name[variable_name_length - 8], "_density") == 0 ||
+                strcmp(&variable->name[variable_name_length - 8], "_apriori") == 0 ||
+                strcmp(&variable->name[variable_name_length - 4], "_avk") == 0 ||
+                strcmp(&variable->name[variable_name_length - 4], "_dfs") == 0)
+            {
+                return resample_interval;
+            }
         }
     }
 
@@ -585,7 +583,7 @@ int harp_product_clamp_dimension(harp_product *product, harp_dimension_type dime
  */
 
 /**
- * Resample all variables in product against a specified grid.
+ * Resample all variables in the product against a specified grid.
  * The target grid variable should be an axis variable containing the target grid (as 'double' values).
  * It should be a one-dimensional variable (for a time independent grid or when regridding in the time dimension)
  * or a two-dimensional variable (for a time dependent grid when not regridding in the time dimension).
@@ -620,7 +618,7 @@ LIBHARP_API int harp_product_regrid_with_axis_variable(harp_product *product, ha
     long source_grid_num_dim_elements;
     long target_grid_max_dim_elements;
     long target_grid_num_dim_elements;
-    long source_num_time_elements;
+    long grid_num_time_elements = 1;
     int source_grid_num_dims = 1;
     int target_grid_num_dims;
     int out_of_bound_flag;
@@ -669,6 +667,7 @@ LIBHARP_API int harp_product_regrid_with_axis_variable(harp_product *product, ha
     }
     target_grid_max_dim_elements = target_grid->dimension[target_grid_num_dims - 1];
 
+    /* we create a local copy so we can modify it for logarithmic interpolation */
     if (harp_variable_copy(target_grid, &local_target_grid) != 0)
     {
         goto error;
@@ -716,8 +715,6 @@ LIBHARP_API int harp_product_regrid_with_axis_variable(harp_product *product, ha
 
     if (dimension_type == harp_dimension_time)
     {
-        source_num_time_elements = 1;
-
         /* Derive the source grid */
         if (harp_product_get_derived_variable(product, target_grid->name, &target_grid->data_type, target_grid->unit, 1,
                                               target_grid->dimension_type, &source_grid) != 0)
@@ -731,14 +728,6 @@ LIBHARP_API int harp_product_regrid_with_axis_variable(harp_product *product, ha
     {
         harp_dimension_type grid_dim_type[2];
 
-        if (product->dimension[harp_dimension_time] == 0)
-        {
-            /* if the product did not have a time dimension then introduce one with length 1
-             * all variables that will be regridded will have this dimension added as first dimension */
-            product->dimension[harp_dimension_time] = 1;
-        }
-        source_num_time_elements = product->dimension[harp_dimension_time];
-
         grid_dim_type[0] = harp_dimension_time;
         grid_dim_type[1] = dimension_type;
 
@@ -753,10 +742,16 @@ LIBHARP_API int harp_product_regrid_with_axis_variable(harp_product *product, ha
             {
                 goto error;
             }
+            grid_num_time_elements = product->dimension[harp_dimension_time];
             source_grid_num_dims = 2;
         }
         source_grid_max_dim_elements = source_grid->dimension[source_grid->num_dimensions - 1];
         source_max_dim_elements = source_grid_max_dim_elements;
+
+        if (target_grid->num_dimensions == 2 || source_grid->num_dimensions == 2)
+        {
+            grid_num_time_elements = product->dimension[harp_dimension_time];
+        }
     }
 
     /* derive bounds variables if necessary for resampling */
@@ -882,11 +877,11 @@ LIBHARP_API int harp_product_regrid_with_axis_variable(harp_product *product, ha
         }
 
         /* Make time independent variables time dependent if source grid or target grid is 2D (i.e. time dependent) */
-        if (source_grid_num_dims > 1 || target_grid_num_dims > 1)
+        if (target_grid->num_dimensions == 2 || source_grid->num_dimensions == 2)
         {
             if (variable->dimension_type[0] != harp_dimension_time)
             {
-                if (harp_variable_add_dimension(variable, 0, harp_dimension_time, source_num_time_elements) != 0)
+                if (harp_variable_add_dimension(variable, 0, harp_dimension_time, grid_num_time_elements) != 0)
                 {
                     goto error;
                 }
@@ -931,7 +926,7 @@ LIBHARP_API int harp_product_regrid_with_axis_variable(harp_product *product, ha
             long k, l;
 
             /* keep track of time index for 2D grids */
-            if (j % (num_blocks / source_num_time_elements) == 0)
+            if (j % (num_blocks / grid_num_time_elements) == 0)
             {
                 if (source_grid_num_dims == 2 && j > 0)
                 {
