@@ -366,8 +366,14 @@ def _get_c_library_filename():
     if os.path.exists(library_path):
         return library_path
 
-    # otherwise assume the library to be in the parent library directory
-    return os.path.normpath(os.path.join(os.path.dirname(__file__), "../../..", library_name))
+    # assume the library to be in the parent library directory
+    library_path = os.path.normpath(os.path.join(os.path.dirname(__file__), "../../..", library_name))
+    if not os.path.exists(library_path):
+        # on RHEL the python path uses lib64, but the library might have gotten installed into lib
+        alt_library_path = os.path.normpath(os.path.join(os.path.dirname(__file__), "../../../../lib", library_name))
+        if os.path.exists(alt_library_path):
+            return alt_library_path
+    return library_path
 
 
 def _get_filesystem_encoding():
@@ -823,11 +829,11 @@ def _import_product_metadata(c_metadata):
     if numpy.isinf(c_metadata.datetime_start):
         metadata['datetime_start'] = datetime.datetime.min
     else:
-        metadata['datetime_start'] = datetime.datetime(2000,1,1) + datetime.timedelta(days=c_metadata.datetime_start)
+        metadata['datetime_start'] = datetime.datetime(2000, 1, 1) + datetime.timedelta(days=c_metadata.datetime_start)
     if numpy.isinf(c_metadata.datetime_stop):
         metadata['datetime_stop'] = datetime.datetime.max
     else:
-        metadata['datetime_stop'] = datetime.datetime(2000,1,1) + datetime.timedelta(days=c_metadata.datetime_stop)
+        metadata['datetime_stop'] = datetime.datetime(2000, 1, 1) + datetime.timedelta(days=c_metadata.datetime_stop)
 
     metadata['time'] = c_metadata.dimension[0]
     metadata['latitude'] = c_metadata.dimension[1]
@@ -902,13 +908,13 @@ def _export_variable(name, variable, c_product):
             min_data_type = _get_c_data_type(variable.valid_min)
             if min_data_type != c_data_type:
                 c_data_type = min_data_type
-        except:
+        except Exception:
             pass
         try:
             max_data_type = _get_c_data_type(variable.valid_max)
             if max_data_type != c_data_type:
                 c_data_type = max_data_type
-        except:
+        except Exception:
             pass
 
     # Encode variable name.
@@ -1176,7 +1182,7 @@ def import_product(filename, operations="", options="", reduce_operations="", po
                         if _lib.harp_product_execute_operations(merged_product_ptr[0],
                                                                 _encode_string(reduce_operations)) != 0:
                             raise CLibraryError()
-        except:
+        except Exception:
             if merged_product_ptr is not None:
                 _lib.harp_product_delete(merged_product_ptr[0])
             raise
@@ -1434,7 +1440,7 @@ def execute_operations(products, operations="", post_operations=""):
                     _export_product(product, c_product_ptr[0])
                     if _lib.harp_product_execute_operations(c_product_ptr[0], _encode_string(operations)) != 0:
                         raise CLibraryError()
-                except:
+                except Exception:
                     _lib.harp_product_delete(c_product_ptr[0])
                     raise
 
@@ -1451,7 +1457,7 @@ def execute_operations(products, operations="", post_operations=""):
                             raise CLibraryError()
                     finally:
                         _lib.harp_product_delete(c_product_ptr[0])
-        except:
+        except Exception:
             if merged_product_ptr is not None:
                 _lib.harp_product_delete(merged_product_ptr[0])
             raise
